@@ -3,7 +3,7 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2016-02-24
+ *  Updated   : 2016-04-12
  *  Notes     : #include files, #defines & struct's
  *
  * Copyright (c) 1997-2016 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
@@ -906,8 +906,8 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 	 * For CURSOR_ARROW and CURSOR_HORIZ tinrc.utf8_graphics ? :
 	 * is handled inside screen.c:draw_arrow_mark().
 	 */
-#	define CURSOR_ARROW		(wchar_t) 0x25B6
-#	define CURSOR_HORIZ		(wchar_t) 0x2500
+#	define CURSOR_ARROW		(wint_t) 0x25B6
+#	define CURSOR_HORIZ		(wint_t) 0x2500
 #	define TREE_ARROW		(wchar_t) (tinrc.utf8_graphics ? 0x25B6 : '>')
 #	define TREE_ARROW_WRAP	(wchar_t) (tinrc.utf8_graphics ? 0x25B7 : '>')
 #	define TREE_BLANK		(wchar_t) ' '
