@@ -3,7 +3,7 @@
  *  Module    : init.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2016-02-12
+ *  Updated   : 2016-04-17
  *  Notes     :
  *
  * Copyright (c) 1991-2016 Iain Lea <iain@bricbrac.de>
@@ -385,7 +385,9 @@ struct t_config tinrc = {
 #else
 	FALSE,		/* start_editor_offset */
 #endif /* M_UNIX */
+#ifndef USE_CURSES
 	TRUE,		/* strip_blanks */
+#endif /* !USE_CURSES */
 	FALSE,		/* strip_newsrc */
 	FALSE,		/* tex2iso_conv */
 	TRUE,		/* thread_catchup_on_exit */
@@ -689,8 +691,9 @@ init_selfinfo(
 		error_message(2, _(txt_error_passwd_missing));
 		free(tin_progname);
 		giveup();
-	} else
-		my_strncpy(userid, myentry->pw_name, sizeof(userid) - 1);
+	}
+
+	my_strncpy(userid, myentry->pw_name, sizeof(userid) - 1);
 
 	if (((ptr = getenv("TIN_HOMEDIR")) != NULL) && strlen(ptr)) {
 		my_strncpy(homedir, ptr, sizeof(homedir) - 1);
